From 421195ed7c2564b3ccbc0296a3510fec52ceea0b Mon Sep 17 00:00:00 2001
From: Chris Lamb <chris@chris-lamb.co.uk>
Date: Mon, 13 Aug 2018 17:45:16 +0200
Subject: [PATCH 2/2] Prevent change of gid of debian-tor user breaking
 automatic upgrades. (Closes: #15695)

As outlined in a774ba2aba7012f3f5bc630b0f3dab8ac696dbd7, since the
virtualbox 5.2.8-dfsg-7 upload the virtualbox-guest-utils package depends
on virtualbox-guest-dkms which in-turn creates a "vboxsf" group later than
before.

This results in the resulting debian-tor group ID being assigned a
different number due to change of relative ordering and, accordingly,
breaks automatic upgrades.

We therefore assign a number of groups, fresh, unreserved group IDs to
avoid collisions.
---
 .../04-change-gids-and-uids                   | 23 +++++++++++--------
 1 file changed, 14 insertions(+), 9 deletions(-)

diff --git a/config/chroot_local-hooks/04-change-gids-and-uids b/config/chroot_local-hooks/04-change-gids-and-uids
index 23c91e618f..911dd05701 100755
--- a/config/chroot_local-hooks/04-change-gids-and-uids
+++ b/config/chroot_local-hooks/04-change-gids-and-uids
@@ -7,11 +7,11 @@ set -e
 echo "Change GIDs and UIDs"
 
 Change_uid () {
-	OLD="$1"
+	NAME="$1"
 	NEW="$2"
-	NAME=$(getent passwd "$OLD" | awk -F ':' '{print $1}')
+	OLD="$(getent passwd "$NAME" | awk -F ':' '{print $3}')"
 
-	if [ -n "$NAME" ]; then
+	if [ -n "$OLD" ]; then
 		echo "Changing UID for $NAME ($OLD -> $NEW)"
 		usermod --uid "$NEW" "$NAME"
 		find / -wholename /proc -prune -o \( \! -type l -a -uid "$OLD" -exec chown "$NEW" '{}' \; \)
@@ -19,11 +19,11 @@ Change_uid () {
 }
 
 Change_gid () {
-	OLD="$1"
+	NAME="$1"
 	NEW="$2"
-	NAME=$(getent group "$OLD" | awk -F ':' '{print $1}')
+	OLD="$(getent group "$NAME" | awk -F ':' '{print $3}')"
 
-	if [ -n "$NAME" ]; then
+	if [ -n "$OLD" ]; then
 		echo "Changing GID for $NAME ($OLD -> $NEW)"
 		usermod --gid "$NEW" "$NAME"
 		find / -wholename /proc -prune -o \( \! -type l -a -gid "$OLD" -exec chgrp "$NEW" '{}' \; \)
@@ -31,6 +31,11 @@ Change_gid () {
 }
 
 
-# tails-persistent-setup
-Change_uid 115 150
-Change_gid 122 150
+Change_uid tails-persistent-setup 150
+Change_gid tails-persistent-setup 150
+
+# Ensure debian-tor's gid remains does not break upgrades (#15695)
+Change_gid monkeysphere 151
+Change_gid debian-tor 152
+Change_gid lpadmin 153
+Change_gid vboxsf 154
-- 
2.18.0

